@@ -147,7 +147,11 @@ sub _parse_first_line {
 
     my $status = $self->status;
     unless ($line =~ m{^HTTP/1\.1 $status }) {
-        $self->error('Wrong response line');
+        my $vis = $line;
+        if( length( $vis ) > 80 ) {
+            substr( $vis, 77 )= '...';
+        }
+        $self->error('Wrong response line. Got [[' . $vis . "]], expected [[HTTP/1.1 $status ]]");
         return;
     }
 
